@@ -5,42 +5,38 @@ from mixcoatl.decorators.validations import required_attrs
 from mixcoatl.decorators.lazy import lazy_property
 
 import json
+import time
 
 
 class Server(Resource):
     """A server is a virtual machine running within a data center."""
 
-    path = 'infrastructure/Server'
-    collection_name = 'servers'
-    primary_key = 'server_id'
+    PATH = 'infrastructure/Server'
+    COLLECTION_NAME = 'servers'
+    PRIMARY_KEY = 'server_id'
 
     def __init__(self, server_id=None, *args, **kwargs):
-        self.collection_name = self.__class__.collection_name
         Resource.__init__(self)
         self.__server_id = server_id
 
     @property
     def server_id(self):
-        """`int` - The enStratus ID of this server. *Immutable*"""
-
+        """`int` - The enStratus ID of this server"""
         return self.__server_id
 
     @lazy_property
     def agent_version(self):
-        """`int` - The version of the enStratus agent if installed. *Immutable*"""
-
+        """`int` - The version of the enStratus agent if installed."""
         return self.__agent_version
 
     @lazy_property
     def cloud(self):
-        """`dict` - The cloud provided where the instance is located. _*Immutable*_"""
-
+        """`dict` - The cloud provided where the instance is located."""
         return self.__cloud
 
     @lazy_property
     def label(self):
         """`str` - The label assigned to the server"""
-
         return self.__label
 
     @label.setter
@@ -49,14 +45,17 @@ class Server(Resource):
 
     @lazy_property
     def customer(self):
-        """`dict` - The customer account for the server. *Immutable*"""
-
+        """`dict` - The customer account for the server."""
         return self.__customer
 
+    @lazy_property
+    def cm_account(self):
+        """`dict` - The configuration management account for the server."""
+        return self.__cm_account
+
     @lazy_property
     def data_center(self):
         """`dict` - The specific datacenter where the instance is located."""
-
         return self.__data_center
 
     @data_center.setter
@@ -66,7 +65,6 @@ class Server(Resource):
     @lazy_property
     def description(self):
         """The description of the server"""
-
         return self.__description
 
     @description.setter
@@ -76,7 +74,6 @@ class Server(Resource):
     @lazy_property
     def machine_image(self):
         """`dict` - The machine image to use/used to provision the server"""
-
         return self.__machine_image
 
     @machine_image.setter
@@ -86,7 +83,6 @@ class Server(Resource):
     @lazy_property
     def firewalls(self):
         """`list` - The firewalls to assign/assigned to the server"""
-
         return self.__firewalls
 
     @firewalls.setter
@@ -96,7 +92,6 @@ class Server(Resource):
     @lazy_property
     def name(self):
         """`str` - The name assigned/to assign to the server"""
-
         return self.__name
 
     @name.setter
@@ -105,44 +100,43 @@ class Server(Resource):
 
     @lazy_property
     def owning_groups(self):
-        """`list` - The enStratus groups owning the server. *Immutable*"""
-
+        """`list` - The enStratus groups owning the server."""
         return self.__owning_groups
 
     @lazy_property
     def owning_user(self):
-        """`dict` - The enStratus user owning the server. *Immutable*"""
-
+        """`dict` - The enStratus user owning the server."""
         return self.__owning_user
 
     @lazy_property
     def platform(self):
-        """`str` - The platform of the server *(i.e. `UBUNTU`)*. *Immutable*"""
-
+        """`str` - The platform of the server *(i.e. `UBUNTU`)*."""
         return self.__platform
 
+    @lazy_property
+    def personalities(self):
+        """`dict` - The personalities associated with the server"""
+        return self.__personalities
+
     @lazy_property
     def private_ip_addresses(self):
-        """`list` - The private ip addresses assigned to the server. *Immutable*"""
+        """`list` - The private ip addresses assigned to the server."""
 
         return self.__private_ip_addresses
 
     @lazy_property
     def public_ip_address(self):
-        """`str` - The public ip address of the server. *Immutable*"""
-
+        """`str` - The public ip address of the server."""
         return self.__public_ip_address
 
     @lazy_property
     def region(self):
         """`dict` - The region where the server is located"""
-
         return self.__region
 
     @lazy_property
     def provider_product_id(self):
         """`str` - The provider's product identifier for the server *(i.e. `m1.large`)*"""
-
         return self.__provider_product_id
 
     @provider_product_id.setter
@@ -151,32 +145,32 @@ class Server(Resource):
 
     @lazy_property
     def provider_id(self):
-        """`str` - The provider's identifier for the server *(i.e. `i-abcdefg`)* *Immutable*"""
-
+        """`str` - The provider's identifier for the server *(i.e. `i-abcdefg`)*"""
         return self.__provider_id
 
     @lazy_property
     def product(self):
-        """The enStratus product record for the server"""
-
+        """`dict` - The enStratus product record for the server"""
         return self.__product
 
     @lazy_property
     def start_date(self):
         """`str` - The date the server was started"""
-
         return self.__start_date
 
     @lazy_property
-    def status(self):
-        """`str` - The status of the server *(i.e. `RUNNING` or `PAUSED`)*. *Immutable*"""
+    def stop_date(self):
+        """`str` - The date the server was stopped"""
+        return self.__stop_date
 
+    @lazy_property
+    def status(self):
+        """`str` - The status of the server *(i.e. `RUNNING` or `PAUSED`)*."""
         return self.__status
 
     @lazy_property
     def budget(self):
         """`int` - The budget code to apply/applied to the server."""
-
         return self.__budget
 
     @property
@@ -187,7 +181,6 @@ class Server(Resource):
                 enStratus does not track keypairs used to launch servers.
                 This attribute is used only in the `launch()` call.
         """
-
         return self.__keypair
 
     @keypair.setter
@@ -196,14 +189,14 @@ class Server(Resource):
 
     def reload(self):
         """Reload resource data from API calls"""
-
         if self.server_id is not None:
             self.load()
         elif self.current_job is None:
             self.load()
         else:
             if Job.wait_for(self.current_job):
-                self.__server_id = job.get(self.current_job)['message']
+                job = Job(self.current_job)
+                self.__server_id = job.message
                 self.load()
             else:
                 return self.last_error
@@ -216,13 +209,13 @@ class Server(Resource):
         :type reason: str.
         :returns: bool -- Result of API call
         """
-        p = self.path+"/"+str(self.server_id)
+        p = self.PATH+"/"+str(self.server_id)
         qopts = {'reason':reason}
         return self.delete(p, params=qopts)
 
     @required_attrs(['server_id'])
     def pause(self, reason=None):
-        p = '%s/%s' % (self.path, str(self.server_id))
+        p = '%s/%s' % (self.PATH, str(self.server_id))
         payload = {'pause':[{}]}
 
         if reason is not None:
@@ -273,12 +266,12 @@ class Server(Resource):
             except AttributeError:
                 pass
 
-        s = self.post(data=json.dumps(payload))
+        self.post(data=json.dumps(payload))
         if self.last_error is None:
             if callback is not None:
-                callback(s)
+                callback(self.current_job)
             else:
-                return s
+                return self.current_job
         else:
             raise ServerLaunchException(self.last_error)
 
@@ -311,7 +304,7 @@ class Server(Resource):
                 callback(self)
             else:
                 return self
-                
+
     @classmethod
     def all(cls):
         """Get a list of all known servers
@@ -322,11 +315,11 @@ class Server(Resource):
         :returns: list -- a list of :class:`Server`
         :raises: ServerException
         """
-        r = Resource(cls.path)
+        r = Resource(cls.PATH)
         r.request_details = 'basic'
         s = r.get()
         if r.last_error is None:
-            servers = [cls(server['serverId']) for server in s[cls.collection_name]]
+            servers = [cls(server['serverId']) for server in s[cls.COLLECTION_NAME]]
             return servers
         else:
             raise ServerException(r.last_error)
